5.1.7 - 2025-04-03
^^^^^^^^^^^^^^^^^^
- Modify nox build, dependency, and test, and remove image sessions.
- Modify documentation.
- Modify requirements.

5.1.5 - 2025-01-17
^^^^^^^^^^^^^^^^^^
- Modify FirFilter and IirFilter frequency and order constraints.

5.1.4 - 2025-01-08
^^^^^^^^^^^^^^^^^^
- Modify dependency generation which does not yet support Python 3.13.
- Modify requirements.

5.1.2 - 2025-01-07
^^^^^^^^^^^^^^^^^^
- Refactor and simplify typing declarations.
- Remove support for Python 3.9.
- Add support for Python 3.13.

5.1.1 - 2024-08-21
^^^^^^^^^^^^^^^^^^
- Refactor FirFilter scipy firwin argument assignment.
- Modify define version from importlib.
- Modify documentation.

5.1.0 - 2024-06-15
^^^^^^^^^^^^^^^^^^
- Modify pyproject and nox to define and install optional project dependencies.
- Modify nox to support python versions defined in pyproject.
- Modify nox to add lint session.
- Modify file names and format to comply with PEP 8.
- Modify documentation.
- Modify requirements.

5.0.3 - 2024-04-15
^^^^^^^^^^^^^^^^^^
- Modify documentation.
- Modify requirements.

5.0.2 - 2024-03-18
^^^^^^^^^^^^^^^^^^
- Modify documentation.
- Modify requirements.

5.0.1 - 2024-01-23
^^^^^^^^^^^^^^^^^^
- Required pillow 10.2.0 to address pillow arbitrary code execution.
- Modify requirements.

5.0.0 - 2023-11-01
^^^^^^^^^^^^^^^^^^
- Renamed PowerSpectrumTransform PsdTransform.
- Modify documentation.
- Modify tests.

4.1.18 - 2023-10-26
^^^^^^^^^^^^^^^^^^^
- Modify requirements.

4.1.17 - 2023-10-06
^^^^^^^^^^^^^^^^^^^
- Required pillow 10.0.1 to address pillow libwebp dependency.
- Modify requirements.

4.1.16 - 2023-10-01
^^^^^^^^^^^^^^^^^^^
- Optimized PowerSpectrumTransform.

4.1.15 - 2023-09-29
^^^^^^^^^^^^^^^^^^^
- Modify constant string comparisons to be case insensitive.
- Modify docstring latex format.
- Modify list to numpy array conversion.
- Modify IirFilter and DiversityModel order range.
- Modify exception format.

4.1.14 - 2023-07-14
^^^^^^^^^^^^^^^^^^^
- Modify for type checking compliance.
- Modify nox.

4.1.13 - 2023-06-06
^^^^^^^^^^^^^^^^^^^
- Modify PolynomialRateFilter and PolyphaseRateFilter.

4.1.11 - 2023-06-05
^^^^^^^^^^^^^^^^^^^
- Modify PolynomialRateFilter.

4.1.10 - 2023-05-03
^^^^^^^^^^^^^^^^^^^
- Modify requirements.

4.1.9 - 2023-04-24
^^^^^^^^^^^^^^^^^^
- Modify requirements.

4.1.8 - 2023-03-26
^^^^^^^^^^^^^^^^^^
- Modify Serial encode indent.

4.1.7 - 2023-02-22
^^^^^^^^^^^^^^^^^^
- Modify RestClient for header and authorization.

4.1.6 - 2023-01-11
^^^^^^^^^^^^^^^^^^
- Modify requirements.
- Modify documentation.

4.1.5 - 2022-12-09
^^^^^^^^^^^^^^^^^^
- Modify requirements.
- Modify documentation.

4.1.4 - 2022-11-13
^^^^^^^^^^^^^^^^^^
- Modify PowerSpectrumTransform.

4.1.3 - 2022-11-01
^^^^^^^^^^^^^^^^^^
- Modify PowerSpectrumTransform.

4.1.2 - 2022-10-31
^^^^^^^^^^^^^^^^^^
- Modify FirFilter and IirFilter.
- Modify PolynomialRateFilter.

4.1.1 - 2022-10-24
^^^^^^^^^^^^^^^^^^
- Modify GoertzelFilter, FourierTransform, and PowerSpectrumTransform.

4.1.0 - 2022-10-17
^^^^^^^^^^^^^^^^^^
- Modify documentation.
- Modify IirFilter and PolynomialRateFilter.
- Modify requirements.

4.0.3 - 2022-08-18
^^^^^^^^^^^^^^^^^^
- Modify documentation.
- Modify nox.
- Modify setup.

4.0.2 - 2022-04-07
^^^^^^^^^^^^^^^^^^
- Modify documentation.
- Modify nox.
- Modify setup.

4.0.1 - 2022-03-24
^^^^^^^^^^^^^^^^^^
- Modify requirements.

4.0.0 - 2022-03-24
^^^^^^^^^^^^^^^^^^
- Add GaussianModel and GaussianMixtureModel.
- Remove PrincipalComponentModel.
- Modify DiversityModel.
- Modify jupyter notebook.
- Modify requirements.

3.0.3 - 2022-01-26
^^^^^^^^^^^^^^^^^^
- Modify requirements.

3.0.2 - 2022-01-20
^^^^^^^^^^^^^^^^^^
- Modify setup.

3.0.1 - 2022-01-19
^^^^^^^^^^^^^^^^^^
- Modify documentation.
- Modify requirements.

3.0.0 - 2021-11-19
^^^^^^^^^^^^^^^^^^
- Remove interfaces.
- Modify RankFilter.
- Modify documentation.

2.1.1 - 2021-10-08
^^^^^^^^^^^^^^^^^^
- Modify IirFilter and FirFilter.

2.1.0 - 2021-10-07
^^^^^^^^^^^^^^^^^^
- Modify interfaces.
- Remove Factory definitions.
- Modify documentation and format.
- Modify jupyter notebook.

2.0.1 - 2021-09-29
^^^^^^^^^^^^^^^^^^
- Restored IPeriod.

2.0.0 - 2021-09-27
^^^^^^^^^^^^^^^^^^
- Remove several interfaces, including IEqual.
- Remove equality definitions.
- Modify documentation and format.

1.0.99 - 2021-09-21
^^^^^^^^^^^^^^^^^^^
- Modify requirements.

1.0.98 - 2021-07-07
^^^^^^^^^^^^^^^^^^^
- Modify typing and requirements.

1.0.97 - 2021-06-04
^^^^^^^^^^^^^^^^^^^
- Modify typing imports and declarations.

1.0.96 - 2021-06-04
^^^^^^^^^^^^^^^^^^^
- Modify license format, no change in terms.

1.0.95 - 2021-05-27
^^^^^^^^^^^^^^^^^^^
- Modify requirements.

1.0.94 - 2021-05-27
^^^^^^^^^^^^^^^^^^^
- Modify requirements.

1.0.93 - 2021-05-21
^^^^^^^^^^^^^^^^^^^
- Modify setup and nox.

1.0.92 - 2021-05-13
^^^^^^^^^^^^^^^^^^^
- Modify setup, nox, and documentation.

1.0.91 - 2021-05-12
^^^^^^^^^^^^^^^^^^^
- Modify documentation.

1.0.90 - 2021-05-11
^^^^^^^^^^^^^^^^^^^
- Modify setup.

1.0.89 - 2021-05-11
^^^^^^^^^^^^^^^^^^^
- Modify imports.

1.0.88 - 2021-05-07
^^^^^^^^^^^^^^^^^^^
- Modify tests.

1.0.87 - 2021-05-06
^^^^^^^^^^^^^^^^^^^
- Modify requirements.
- Modify RestClient request.

1.0.86 - 2021-05-03
^^^^^^^^^^^^^^^^^^^
- Modify typing.
- Remove IAsset, ICache, ICompress, IConnect, IEmulate,
  IEncoding, IHeader, and IUpdate.
- Modify IirFilter to remove IQ.
- Modify RestClient to remove IReady and IVersion.

1.0.85 - 2021-05-01
^^^^^^^^^^^^^^^^^^^
- Modify typing and cleaned declarations.
- Remove IUser.

1.0.84 - 2021-04-28
^^^^^^^^^^^^^^^^^^^
- Modify requirements to remove dateutil.

1.0.83 - 2021-04-23
^^^^^^^^^^^^^^^^^^^
- Modify requirements.

1.0.82 - 2021-04-14
^^^^^^^^^^^^^^^^^^^
- Modify documentation.

1.0.81 - 2021-04-13
^^^^^^^^^^^^^^^^^^^
- Modify Log minimum level.

1.0.80 - 2021-04-13
^^^^^^^^^^^^^^^^^^^
- Modify Log format and added lazy initialization of loguru.

1.0.79 - 2021-04-01
^^^^^^^^^^^^^^^^^^^
- Modify interface initializations.

1.0.78 - 2021-03-30
^^^^^^^^^^^^^^^^^^^
- Modify documentation.

1.0.77 - 2021-03-25
^^^^^^^^^^^^^^^^^^^
- Modify IirFilter filter.

1.0.76 - 2021-03-25
^^^^^^^^^^^^^^^^^^^
- Modify FirFilter and IirFilter to deprecate use of IRate.

1.0.75 - 2021-03-16
^^^^^^^^^^^^^^^^^^^
- Modify Serial to use Base-85 encoded gzip JSON, and compact separators.

1.0.74 - 2021-03-15
^^^^^^^^^^^^^^^^^^^
- Modify init.

1.0.73 - 2021-03-15
^^^^^^^^^^^^^^^^^^^
- Add ILabel.

1.0.72 - 2021-03-14
^^^^^^^^^^^^^^^^^^^
- Modify RestClient to use IHeader, deprecate caching and return
  requests response.

1.0.71 - 2021-03-12
^^^^^^^^^^^^^^^^^^^
- Modify RestClient exceptions.

1.0.70 - 2021-03-05
^^^^^^^^^^^^^^^^^^^
- Modify jupyter.

1.0.69 - 2021-03-05
^^^^^^^^^^^^^^^^^^^
- Modify strings to f-strings.

1.0.68 - 2021-03-03
^^^^^^^^^^^^^^^^^^^
- Modify jupyter.

1.0.67 - 2021-03-03
^^^^^^^^^^^^^^^^^^^
- Modify RestClient package.

1.0.66 - 2021-03-03
^^^^^^^^^^^^^^^^^^^
- Modify Log exceptions.

1.0.65 - 2021-03-03
^^^^^^^^^^^^^^^^^^^
- Modify Log format.

1.0.64 - 2021-03-02
^^^^^^^^^^^^^^^^^^^
- Modify Log to define any entry.

1.0.63 - 2021-03-02
^^^^^^^^^^^^^^^^^^^
- Modify Log to use loguru and deprecate logging.

1.0.62 - 2021-02-26
^^^^^^^^^^^^^^^^^^^
- Modify Serial code.

1.0.61 - 2021-02-16
^^^^^^^^^^^^^^^^^^^
- Modify RestClient.

1.0.60 - 2021-02-08
^^^^^^^^^^^^^^^^^^^
- Modify RestClient live, ready, and version.
- Modify IUrl.

1.0.59 - 2021-02-03
^^^^^^^^^^^^^^^^^^^
- Modify documentation.

1.0.58 - 2021-02-03
^^^^^^^^^^^^^^^^^^^
- Modify RestClient to remove IUser.

1.0.57 - 2021-02-01
^^^^^^^^^^^^^^^^^^^
- Modify requirements, Remove pytz dependency.

1.0.56 - 2021-02-01
^^^^^^^^^^^^^^^^^^^
- Modify requirements.

1.0.55 - 2021-02-01
^^^^^^^^^^^^^^^^^^^
- Add IAsset.

1.0.54 - 2021-01-26
^^^^^^^^^^^^^^^^^^^
- Modify RestClient to use IClear.

1.0.53 - 2021-01-21
^^^^^^^^^^^^^^^^^^^
- Modify RestClient request to return JSON, binary, or text response.

1.0.52 - 2021-01-20
^^^^^^^^^^^^^^^^^^^
- Add ITimeOut.
- Modify RestClient to use ITimeOut.

1.0.51 - 2021-01-18
^^^^^^^^^^^^^^^^^^^
- Modify Log and RestClient RLock.

1.0.50 - 2021-01-17
^^^^^^^^^^^^^^^^^^^
- Modify Log and RestClient Lock.

1.0.49 - 2021-01-15
^^^^^^^^^^^^^^^^^^^
- Modify RestClient to return binary data on JSON conversion exception.

1.0.48 - 2021-01-12
^^^^^^^^^^^^^^^^^^^
- Add ILive and IReady.
- Modify RestClient to use ILive, IReady, IUser, and IVersion.
- Modify RestClient request to deprecate retry and migrate cache
  specification.

1.0.47 - 2021-01-08
^^^^^^^^^^^^^^^^^^^
- Modify RestClient request to delay on retry.

1.0.46 - 2021-01-08
^^^^^^^^^^^^^^^^^^^
- Add ICount.

1.0.45 - 2021-01-07
^^^^^^^^^^^^^^^^^^^
- Modify RestClient request Log entries.

1.0.44 - 2021-01-07
^^^^^^^^^^^^^^^^^^^
- Modify RestClient request retry status 5xx.

1.0.43 - 2021-01-07
^^^^^^^^^^^^^^^^^^^
- Modify RestClient request retry status 5xx.

1.0.42 - 2021-01-06
^^^^^^^^^^^^^^^^^^^
- Modify RestClient request timeout.

1.0.41 - 2020-12-11
^^^^^^^^^^^^^^^^^^^
- Modify requirements.

1.0.40 - 2020-12-11
^^^^^^^^^^^^^^^^^^^
- Modify IUser to recover from getpass failure.

1.0.39 - 2020-11-25
^^^^^^^^^^^^^^^^^^^
- Modify IClear, IReset, and IUpdate.
- Renamed IState to IModel.

1.0.38 - 2020-11-20
^^^^^^^^^^^^^^^^^^^
- Modify RestClient live.
- Modify init to simplify import, eliminating required package declaration.

1.0.37 - 2020-11-19
^^^^^^^^^^^^^^^^^^^
- Modify RestClient cache.

1.0.36 - 2020-11-19
^^^^^^^^^^^^^^^^^^^
- Modify RestClient cache and live, and deprecate ready.

1.0.35 - 2020-11-16
^^^^^^^^^^^^^^^^^^^
- Modify RestClient request to add timeout.

1.0.34 - 2020-11-11
^^^^^^^^^^^^^^^^^^^
- Modify RestClient to add json and binary data body support.

1.0.33 - 2020-11-10
^^^^^^^^^^^^^^^^^^^
- Add IIdentity.

1.0.32 - 2020-11-09
^^^^^^^^^^^^^^^^^^^
- Modify RestClient to force coercion of item dictionary values to strings.

1.0.31 - 2020-11-06
^^^^^^^^^^^^^^^^^^^
- Modify Serial encode and decode disable compression as default.
- Modify RestClient to strip leading and trailing '/' from URL and API
  properties and arguments.

1.0.30 - 2020-11-04
^^^^^^^^^^^^^^^^^^^
- Modify nox, dependencies, and documentation.

1.0.29 - 2020-11-02
^^^^^^^^^^^^^^^^^^^
- Modify RestClient to remove user and added IUser.

1.0.28 - 2020-10-27
^^^^^^^^^^^^^^^^^^^
- Add IConfigure.
- Modify RequestClient in extend requests support, reduce external
  dependencies, and add data.
- Modify Serial to add support for pandas and register extensions.

1.0.27 - 2020-10-21
^^^^^^^^^^^^^^^^^^^
- Add type hints and Modify documentation.
- Renamed IDateTime to IDate to avoid datetime conflict.
- Add ICompress, IConnect, IDispose, IEmulate, IStream, IValid, and IWrite.
- Add clients subpackage and RestClient.

1.0.26 - 2020-10-13
^^^^^^^^^^^^^^^^^^^
- Add ICache, IProxy, and IUrl.

1.0.25 - 2020-10-12
^^^^^^^^^^^^^^^^^^^
- Add nox sessions with dist, docs, push, and tests methods.

1.0.24 - 2020-09-23
^^^^^^^^^^^^^^^^^^^
- Add IVersion.
- Modify requirements.

1.0.23 - 2020-09-09
^^^^^^^^^^^^^^^^^^^
- Modify documentation, replaced sphinx theme.

1.0.22 - 2020-08-26
^^^^^^^^^^^^^^^^^^^
- Modify documentation.

1.0.21 - 2020-08-19
^^^^^^^^^^^^^^^^^^^
- Modify PolynomialRateFilter to support decimation and interpolation.

1.0.20 - 2020-08-19
^^^^^^^^^^^^^^^^^^^
- Modify documentation.
- Modify jupyter notebook to embed images and improve links.

1.0.19 - 2020-08-18
^^^^^^^^^^^^^^^^^^^
- Modify jupyter notebook to utilize pillow, and eliminate open dependency.
- Modify documentation to run jupyter notebook with binder.

1.0.18 - 2020-08-11
^^^^^^^^^^^^^^^^^^^
- Modify jupyter notebook to improve appearance.

1.0.17 - 2020-08-06
^^^^^^^^^^^^^^^^^^^
- Modify Log to improve exception format.
- Modify jupyter notebook to utilize warnings to ignore import deprecation
  warnings.

1.0.16 - 2020-07-27
^^^^^^^^^^^^^^^^^^^
- Modify documentation.

1.0.15 - 2020-07-22
^^^^^^^^^^^^^^^^^^^
- Modify jupyter notebook to utilize Open CV, and eliminate pillow
  dependency.

1.0.14 - 2020-07-15
^^^^^^^^^^^^^^^^^^^
- Modify Log to integrate reentrant thread safety.

1.0.13 - 2020-05-19
^^^^^^^^^^^^^^^^^^^
- Modify IDateTime.

1.0.12 - 2020-05-14
^^^^^^^^^^^^^^^^^^^
- Add IUpdate.

1.0.11 - 2020-05-13
^^^^^^^^^^^^^^^^^^^
- Modify Log to define and display time zone.
- Add IData, IDateTime, IDuration, IEncoding, IInterval, ILatency, IPath,
  IPeriod, IResolution, IRotation, IState, and ITimeZone.

1.0.10 - 2020-03-08
^^^^^^^^^^^^^^^^^^^
- Modify comments.

1.0.9 - 2020-01-13
^^^^^^^^^^^^^^^^^^
- Modify jupyter notebook Pillow import.

1.0.8 - 2020-01-09
^^^^^^^^^^^^^^^^^^
- Modify Serial encode exceptions.

1.0.7 - 2019-10-23
^^^^^^^^^^^^^^^^^^
- Modify exception format.

1.0.6 - 2019-09-08
^^^^^^^^^^^^^^^^^^
- Modify documentation.

1.0.1 - 2019-09-04
^^^^^^^^^^^^^^^^^^
- Initial release.
